@@ -1,7 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
-// taskwarrior - a command line task list manager.
 //
-// Copyright 2006-2013, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -27,7 +26,6 @@
 
 #ifndef INCLUDED_NIBBLER
 #define INCLUDED_NIBBLER
-#define L10N                                           // Localization complete.
 
 #define NIBBLER_FEATURE_DATE
 //#undef  NIBBLER_FEATURE_DATE
@@ -37,6 +35,7 @@
 
 #include <string>
 #include <vector>
+#include <time.h>
 
 class Nibbler
 {
@@ -64,6 +63,10 @@ public:
   bool getN (const int, std::string&);
   bool getQuoted (char, std::string&, bool quote = false);
   bool getDigit (int&);
+  bool getDigit6 (int&);
+  bool getDigit4 (int&);
+  bool getDigit3 (int&);
+  bool getDigit2 (int&);
   bool getInt (int&);
   bool getHex (int&);
   bool getUnsignedInt (int&);
@@ -77,8 +80,8 @@ public:
   bool getUUID (std::string&);
   bool getPartialUUID (std::string&);
   bool getDateISO (time_t&);
-#ifdef NIBBLER_FEATURE_DATE
   bool parseDigits(std::string::size_type&, int&, unsigned int, bool strict = true);
+#ifdef NIBBLER_FEATURE_DATE
   bool getDate (const std::string&, time_t&);
 #endif
   bool getOneOf (const std::vector <std::string>&, std::string&);
@@ -94,6 +97,8 @@ public:
   bool skipRx (const std::string&);
 #endif
 
+  bool backN (const int quantity = 1);
+
   void getRemainder (std::string&);
 
   char next ();
