@@ -1,7 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
-// taskwarrior - a command line task list manager.
 //
-// Copyright 2006-2014, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -38,7 +37,7 @@ extern Context context;
 ColumnIMask::ColumnIMask ()
 {
   _name       = "imask";
-  _type       = "number";
+  _type       = "numeric";
   _style      = "number";
   _label      = STRING_COLUMN_LABEL_MASK_IDX;
   _modifiable = false;
