@@ -1,7 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
-// taskwarrior - a command line task list manager.
 //
-// Copyright 2006-2013, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -27,7 +26,6 @@
 
 #ifndef INCLUDED_COLSTATUS
 #define INCLUDED_COLSTATUS
-#define L10N                                           // Localization complete.
 
 #include <vector>
 #include <string>
