@@ -1,7 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
-// taskwarrior - a command line task list manager.
 //
-// Copyright 2006-2013, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -25,8 +24,7 @@
 //
 ////////////////////////////////////////////////////////////////////////////////
 
-#define L10N                                           // Localization complete.
-
+#include <cmake.h>
 #include <iostream>
 #include <sstream>
 #include <stdlib.h>
@@ -34,6 +32,8 @@
 #include <unistd.h>
 #include <Duration.h>
 #include <Context.h>
+#include <Filter.h>
+#include <Nibbler.h>
 #include <i18n.h>
 #include <text.h>
 #include <util.h>
@@ -59,21 +59,19 @@ CmdEdit::CmdEdit ()
 // wrench.  To be used sparingly.
 int CmdEdit::execute (std::string& output)
 {
-  int rc = 0;
-
   // Filter the tasks.
   handleRecurrence ();
+  Filter filter;
   std::vector <Task> filtered;
-  filter (filtered);
+  filter.subset (filtered);
 
-  // Find number of matching tasks.  Skip recurring parent tasks.
+  // Find number of matching tasks.
   std::vector <Task>::iterator task;
   for (task = filtered.begin (); task != filtered.end (); ++task)
     if (editFile (*task))
       context.tdb2.modify (*task);
 
-  context.tdb2.commit ();
-  return rc;
+  return 0;
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -98,6 +96,26 @@ std::string CmdEdit::findValue (
   return "";
 }
 
+////////////////////////////////////////////////////////////////////////////////
+std::string CmdEdit::findMultilineValue (
+  const std::string& text,
+  const std::string& startMarker,
+  const std::string& endMarker)
+{
+  std::string::size_type start = text.find (startMarker);
+  if (start != std::string::npos)
+  {
+    std::string::size_type end = text.find (endMarker, start);
+    if (end != std::string::npos)
+    {
+      std::string value = text.substr (start + startMarker.length (),
+                                       end - (start + startMarker.length ()));
+      return trim (value, "\t ");
+    }
+  }
+  return "";
+}
+
 ////////////////////////////////////////////////////////////////////////////////
 std::vector <std::string> CmdEdit::findValues (
   const std::string& text,
@@ -162,8 +180,7 @@ std::string CmdEdit::formatDuration (
 std::string CmdEdit::formatTask (Task task, const std::string& dateformat)
 {
   std::stringstream before;
-  bool verbose = context.verbose ("edit") ||
-                 context.config.getBoolean ("edit.verbose"); // Deprecated 2.0
+  bool verbose = context.verbose ("edit");
 
   if (verbose)
     before << "# " << STRING_EDIT_HEADER_1 << "\n"
@@ -186,7 +203,7 @@ std::string CmdEdit::formatTask (Task task, const std::string& dateformat)
          << "# " << STRING_EDIT_TABLE_HEADER_2 << "\n"
          << "# ID:                " << task.id                                          << "\n"
          << "# UUID:              " << task.get ("uuid")                                << "\n"
-         << "# Status:            " << ucFirst (Task::statusToText (task.getStatus ())) << "\n"
+         << "# Status:            " << ucFirst (Task::statusToText (task.getStatus ())) << "\n"  // L10N safe ucFirst.
          << "# Mask:              " << task.get ("mask")                                << "\n"
          << "# iMask:             " << task.get ("imask")                               << "\n"
          << "  Project:           " << task.get ("project")                             << "\n"
@@ -210,6 +227,7 @@ std::string CmdEdit::formatTask (Task task, const std::string& dateformat)
          << "  Until:             " << formatDate (task, "until", dateformat)           << "\n"
          << "  Recur:             " << task.get ("recur")                               << "\n"
          << "  Wait until:        " << formatDate (task, "wait", dateformat)            << "\n"
+         << "# Modified:          " << formatDate (task, "modified", dateformat)        << "\n"
          << "  Parent:            " << task.get ("parent")                              << "\n";
 
   if (verbose)
@@ -352,7 +370,7 @@ void CmdEdit::parseTask (Task& task, const std::string& after, const std::string
   task.addTags (tags);
 
   // description.
-  value = findValue (after, "\n  Description:");
+  value = findMultilineValue (after, "\n  Description:", "\n  Created:");
   if (task.get ("description") != value)
   {
     if (value != "")
@@ -538,7 +556,8 @@ void CmdEdit::parseTask (Task& task, const std::string& after, const std::string
     if (value != "")
     {
       Duration d;
-      if (d.valid (value))
+      std::string::size_type idx = 0;
+      if (d.parse (value, idx))
       {
         context.footnote (STRING_EDIT_RECUR_MOD);
         if (task.get ("due") != "")
@@ -661,20 +680,10 @@ void CmdEdit::parseTask (Task& task, const std::string& after, const std::string
   std::vector <std::string>::iterator dep;
   for (dep = dependencies.begin (); dep != dependencies.end (); ++dep)
   {
-    std::vector <int> ids;
-
-    // Crude UUID check
-    if (dep->length () == 36)
-    {
-      int id = context.tdb2.pending.id (*dep);
-      ids.push_back (id);
-    }
+    if (dep->length () >= 7)
+      task.addDependency (*dep);
     else
-      A3::extract_id (*dep, ids);
-
-    std::vector <int>::iterator id;
-    for (id = ids.begin (); id != ids.end(); id++)
-      task.addDependency (*id);
+      task.addDependency ((int) strtol (dep->c_str (), NULL, 10));
   }
 
   // UDAs
@@ -686,7 +695,9 @@ void CmdEdit::parseTask (Task& task, const std::string& after, const std::string
     {
       std::string value = findValue (after, "\n  UDA " + col->first + ":");
       if ((task.get (col->first) != value) && (type != "date" ||
-           (task.get (col->first) != Date(value, dateformat).toEpochString ())))
+           (task.get (col->first) != Date (value, dateformat).toEpochString ())) &&
+           (type != "duration" ||
+           (task.get (col->first) != (std::string) Duration (value) )))
       {
         if (value != "")
         {
@@ -725,7 +736,7 @@ void CmdEdit::parseTask (Task& task, const std::string& after, const std::string
       }
     }
   }
-  
+
   // UDA orphans
   std::vector <std::string> orphanValues = findValues (after, "\n  UDA Orphan ");
   std::vector <std::string>::iterator orphan;
