@@ -1,7 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
-// taskwarrior - a command line task list manager.
 //
-// Copyright 2006-2013, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -25,9 +24,9 @@
 //
 ////////////////////////////////////////////////////////////////////////////////
 
-#define L10N                                           // Localization complete.
-
+#include <cmake.h>
 #include <Context.h>
+#include <Filter.h>
 #include <main.h>
 #include <i18n.h>
 #include <CmdExport.h>
@@ -49,12 +48,19 @@ int CmdExport::execute (std::string& output)
 {
   int rc = 0;
 
-  // Apply filter.
-  std::vector <Task> filtered;
-  filter (filtered);
+  // Make sure reccurent tasks are generated.
+  handleRecurrence ();
 
-  // Note: "limit:" feature not supported.
-  // TODO Why not?
+  // Apply filter.
+  Filter filter;
+  std::vector <Task> filtered;
+  filter.subset (filtered);
+
+  // Obey 'limit:N'.
+  int rows = 0;
+  int lines = 0;
+  context.getLimits (rows, lines);
+  int limit = (rows > lines ? rows : lines);
 
   // Is output contained within a JSON array?
   bool json_array = context.config.getBoolean ("json.array");
@@ -63,13 +69,21 @@ int CmdExport::execute (std::string& output)
   if (json_array)
     output += "[\n";
 
+  int counter = 0;
   std::vector <Task>::iterator task;
   for (task = filtered.begin (); task != filtered.end (); ++task)
   {
     if (task != filtered.begin ())
-      output += ",\n";
+      {
+        if (json_array)
+          output += ",";
+        output += "\n";
+      }
 
     output += task->composeJSON (true);
+
+    if (limit && ++counter >= limit)
+      break;
   }
 
   if (filtered.size ())
