@@ -1,7 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
-// taskwarrior - a command line task list manager.
 //
-// Copyright 2006-2013, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -25,12 +24,12 @@
 //
 ////////////////////////////////////////////////////////////////////////////////
 
-#define L10N                                           // Localization complete.
-
+#include <cmake.h>
 #include <algorithm>
 #include <sstream>
 #include <stdlib.h>
 #include <Context.h>
+#include <Filter.h>
 #include <ViewText.h>
 #include <Duration.h>
 #include <text.h>
@@ -59,13 +58,11 @@ int CmdSummary::execute (std::string& output)
 {
   int rc = 0;
 
-  // Scan the pending tasks.
-  handleRecurrence ();
-
   // Apply filter.
+  handleRecurrence ();
+  Filter filter;
   std::vector <Task> filtered;
-  filter (filtered);
-  context.tdb2.commit ();
+  filter.subset (filtered);
 
   // Generate unique list of project names from all pending tasks.
   std::map <std::string, bool> allProjects;
@@ -118,6 +115,7 @@ int CmdSummary::execute (std::string& output)
     }
   }
 
+
   // Create a table for output.
   ViewText view;
   view.width (context.getWidth ());
@@ -129,6 +127,9 @@ int CmdSummary::execute (std::string& output)
 
   Color bar_color (context.config.get ("color.summary.bar"));
   Color bg_color  (context.config.get ("color.summary.background"));
+  Color label     (context.config.get ("color.label"));
+
+  view.colorHeader (label);
 
   int barWidth = 30;
   std::vector <std::string> processed;
